import httpService from "@/request"

// 入住申请-查询所有的入驻申请记录
export function getAllRequest(params) {
	return httpService({
		url: `/user/settledApplication/list`,
		method: 'get',
		params: params,
	})
}

// 入住申请-根据入驻申请主键id查询详情
export function getRequestDetail(params) {
	return httpService({
		url: `/user/settledApplication/findDetailsById`,
		method: 'get',
		params: params,
	})
}

// 入住申请-通过/驳回入驻申请
export function isPass(params) {
	return httpService({
		url: `/user/settledApplication/isPass`,
		method: 'post',
		params: params,
	})
}

// 客户列表-查询所有客户信息
export function getCustomerList(params) {
	return httpService({
		url: `/user/customerList/list`,
		method: 'get',
		params: params,
	})
}

// 客户列表-根据客户主键id查询详情
export function getCustomerDetail(params) {
	return httpService({
		url: `/user/customerList/findDetailsById`,
		method: 'get',
		params: params,
	})
}

// 小区管理-查询所有的小区信息
export function getCommunityList(params) {
	return httpService({
		url: `/user/community/list`,
		method: 'get',
		params: params,
	})
}

// 小区管理-获取对应公司下的所有小区信息
export function getComById(params) {
	return httpService({
		url: `/user/community/getCommunityInfoByCompanyId`,
		method: 'get',
		params: params,
	})
}

// 小区管理-添加小区信息
export function getAddCommunity(params) {
	return httpService({
		url: `/user/community/insertAdmin`,
		method: 'post',
		data: params,
	})
}

// 小区管理-修改小区信息
export function updateCommunity(params) {
	return httpService({
		url: `/user/community/updateAdmin`,
		method: 'post',
		data: params,
	})
}

// 订单管理-查询所有订单
export function getAllOrder(params) {
	return httpService({
		url: `/user/order/list`,
		method: 'get',
		params: params,
	})
}

// 订单管理-后台创建订单
export function createOrder(params) {
	return httpService({
		url: `/user/order/adminCreateOrder`,
		method: 'post',
		data: params,
	})
}

// 订单管理-计算金额
export function calcAmount(params) {
	return httpService({
		url: `/user/order/calculateAmount`,
		method: 'post',
		data: params,
	})
}

// 订单管理-订单解绑小区
export function orderUnbound(params) {
	return httpService({
		url: `/user/order/unbindingCommunity`,
		method: 'get',
		params: params,
	})
}

// 收费管理-收费标准-查询收费模版信息
export function getChargingList(params) {
	return httpService({
		url: `/user/charging/list`,
		method: 'get',
		params: params,
	})
}

// 收费管理-收费标准-查询收费标准时间类型
export function findTimeType(params) {
	return httpService({
		url: `/user/charging/findTimeType`,
		method: 'get',
		params: params,
	})
}

// 收费管理-收费标准-查询收费标准功能模块大类信息
export function findSuperNavigation(params) {
	return httpService({
		url: `/user/charging/findSuperNavigation`,
		method: 'get',
		params: params,
	})
}

// 收费管理-根据收费模版主键Id查询收费模版信息
export function getChargeById(params) {
	return httpService({
		url: `/user/charging/findById`,
		method: 'get',
		params: params,
	})
}

// 收费管理-收费标准-启用/禁用收费模版
export function onoffCharging(params) {
	return httpService({
		url: `/user/charging/updateStatus`,
		method: 'post',
		data: params,
	})
}

// 收费管理-收费标准-添加收费模版
export function addCharge(params) {
	return httpService({
		url: `/user/charging/insert`,
		method: 'post',
		data: params,
	})
}

// 收费管理-收费标准-修改收费模版
export function updateCharge(params) {
	return httpService({
		url: `/user/charging/update`,
		method: 'post',
		data: params,
	})
}

// 收费管理-财务账单-查询所有财务账单
export function getAllList(params) {
	return httpService({
		url: `/user/financialStatements/list`,
		method: 'get',
		params: params,
	})
}

// 收费管理-财务账单-财务账单详情
export function getOrderDetail(params) {
	return httpService({
		url: `/user/financialStatements/findDetails`,
		method: 'get',
		params: params,
	})
}

// 收费管理-财务账单-退款页面回显
export function getPayback(params) {
	return httpService({
		url: `/user/financialStatements/findById`,
		method: 'get',
		params: params,
	})
}

// 收费管理-财务账单-退款
export function postRefund(params) {
	return httpService({
		url: `/user/financialStatements/refund`,
		method: 'post',
		params: params,
	})
}

// 支付设置-查询所有的支付宝设置信息
export function alipayList(params) {
	return httpService({
		url: `/user/alipaySetting/list`,
		method: 'get',
		params: params,
	})
}

// 支付设置-开启/停用支付宝设置信息
export function isEnable(params) {
	return httpService({
		url: `/user/alipaySetting/isEnable`,
		method: 'get',
		params: params,
	})
}

// 支付设置-删除支付宝设置信息
export function alipayDelete(params) {
	return httpService({
		url: `/user/alipaySetting/delete`,
		method: 'post',
		data: params,
	})
}

// 支付设置-添加支付宝设置信息
export function alipayInsert(params) {
	return httpService({
		url: `/user/alipaySetting/insert`,
		method: 'post',
		data: params,
	})
}

// 支付设置-支付宝设置绑定小区
export function alipayBound(params) {
	return httpService({
		url: `/user/alipaySetting/bind`,
		method: 'post',
		data: params,
	})
}

// 支付设置-根据支付宝设置主键id查询支付宝设置绑定信息
export function findBindById(params) {
	return httpService({
		url: `/user/alipaySetting/findBindById`,
		method: 'get',
		params: params,
	})
}

// 支付设置-根据支付宝设置主键id查询支付宝设置信息
export function findInfoById(params) {
	return httpService({
		url: `/user/alipaySetting/findInfoById`,
		method: 'get',
		params: params,
	})
}

// 支付设置-修改支付宝设置信息
export function alipayUpdate(params) {
	return httpService({
		url: `/user/alipaySetting/update`,
		method: 'post',
		data: params,
	})
}